@@ -6,7 +6,7 @@
 ;;         Rémi Vanicat <vanicat@debian.org>
 ;; URL: https://github.com/magit/magit-annex
 ;; Keywords: vc tools
-;; Version: 1.8.0
+;; Version: 1.8.1
 ;; Package-Requires: ((cl-lib "0.3") (magit "3.0.0"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -271,7 +271,7 @@ program used to open the unused file."
 (eval-after-load 'magit
   '(progn
      (define-key magit-mode-map "@" 'magit-annex-dispatch-or-init)
-     (transient-append-suffix 'magit-dispatch "%"
+     (transient-append-suffix 'magit-dispatch '(0 -1 -1)
        '("@" "Annex" magit-annex-dispatch-or-init))))
 
 
